###############################################################################
#                                                                             #
#               Deleting Dynamic Distribution Group for Office 365            #
#                             For Primary Group                               #
#                                    V2.82                                    #
#                       (C)2006-2014 KoXo Developpement                       #
#                                                                             #
###############################################################################
function log_message
{
Param($Header,$Message)	
$LogDate=Get-Date
$LogInfo="[$($LogDate)]: [$($Header)]: $($Message)"
$LogInfo | Out-File -FilePath $LogFile -Encoding Default -Append -Force
}
###############################################################################
function log_errors_count
{
Param($Group)
$S="ErrorsCount[$($Group)]=$($global:errors_count)"
$S | Out-File -FilePath $LogFile -Encoding Default -Append -Force
}
###############################################################################
function log_total_errors_count
{
$S="TotalErrorsCount=$($global:total_errors_count)"
$S | Out-File -FilePath $LogFile -Encoding Default -Append -Force
}
###############################################################################
function check_version
{
$S=Get-Host
if ($S.Version.Major -lt "2")
   {
   $S="Powershell's version must be greater or equal to 2.0 !"
   log_message "Version" $S
   $global:total_errors_count++
   write-host $S -foregroundcolor "red"
   write-host "Press 'Enter' to continue ..."
   Read-Host
   exit
   }
}
###############################################################################
function welcome
{
write-host "Deleting dynamic distribution group for Office 365 $($Version)" -foregroundcolor "white"
write-host "(C) 2006-2014 KoXo Developpement" -foregroundcolor "white"
}
###############################################################################
function connect
{
Param([string] $MyURL,$MyName,$MyPassword,$ProxyEnabled,$ProxyUser,$ProxyPassword)
$error.Clear()
#Proxy
if ($ProxyEnabled)
   {
   if (![String]::IsNullorEmpty($ProxyUser))
      { 
      $SecuredPassword=ConvertTo-SecureString $ProxyPassword -AsPlainText -Force
      $ProxyCred=New-Object System.Management.Automation.PSCredential $ProxyUser, $SecuredPassword
      $PSSessionOption=New-PSSessionOption -ProxyAccessType IEConfig -ProxyAuthentication Negotiate -ProxyCredential $ProxyCred
      $S="Connection with Internet Explorer proxy parameters, User=$($ProxyUser)"
	  log_message "OK" $S
      }
      else 
      {
      $PSSessionOption=New-PSSessionOption -ProxyAccessType IEConfig -ProxyAuthentication Negotiate
      $S="Connection with Internet Explorer proxy parameters"
	  log_message "OK" $S
      }
   write-host $S -foregroundcolor "cyan"   
   }
# Set credential
if ( ([String]::IsNullorEmpty($MyPassword)) -or ([String]::IsNullorEmpty($MyName))  )
   {
   $Cred=Get-Credential
   }
   else
   {
   $SecuredPassword=ConvertTo-SecureString $MyPassword -AsPlainText -Force
   $Cred=New-Object System.Management.Automation.PSCredential $MyName, $SecuredPassword
   }
# Creating new runspace. 
if ($ProxyEnabled)
   {
   $Script:RS=New-PSSession -ConfigurationName microsoft.exchange -ConnectionUri $MyURL -Credential $Cred -Authentication Basic -AllowRedirection -SessionOption $PSSessionOption -ErrorAction SilentlyContinue
   }
   else
   {
   $Script:RS=New-PSSession -ConfigurationName microsoft.exchange -ConnectionUri $MyURL -Credential $Cred -Authentication Basic -AllowRedirection -ErrorAction SilentlyContinue
   }
if ([String]::IsNullorEmpty($error[0]))
   {
    $S="Runspace Creation was successful = $($MyURL)"
	log_message "OK" $S
	# Import-PSSession $Script:RS
   } 
   else 
   {
   $global:total_errors_count++
   $S="Runspace creation was unsuccessful to $($MyURL) || $($error[0])"
   log_message "ERROR" $S
   # Display error
   write-host $S -foregroundcolor "red"
   write-host "Press 'Enter' to continue ..."
   Read-Host   
   }   
 return $Cred
}
###############################################################################
function close
{
$error.Clear()
$Script:RS | Remove-PSSession -ErrorAction SilentlyContinue
if ([String]::IsNullorEmpty($error[0]))
	{
    $S="Successfully cleared Runspace"
	log_message "OK" $S
	}
	else
	{
	$global:total_errors_count++
    $S="Clearing Runspace was unsuccessful. Error = $($error[0])"
    log_message "ERROR" $S
	}
}
###############################################################################
function dynamic_group_exists
{
Param([string] $grp)
$error.Clear()
$Group=Invoke-Command -Session $Script:RS -ErrorAction SilentlyContinue -arg $grp {Param($id) get-dynamicdistributiongroup -Identity $id}
return (![string]::IsNullOrEmpty($Group))
}
###############################################################################
function delete_dynamic_distribution_group
{
Param($GroupName, 
      $GroupAlias,
      $GroupDisplayName,
      $GroupEmail)
$error.Clear()
%{Invoke-Command -Session $Script:RS {param ($name) remove-dynamicdistributiongroup -Identity $name -Confirm:$false}-arg $GroupName}>$Results
if ([String]::IsNullorEmpty($error[0]))
	{
    $S="Successfully delete dynamic distribution group ""$($GroupName)"" DisplayName=""$($GroupDisplayName)"", Alias=""$($GroupAlias)"""
	log_message "OK" $S
	}
	else
	{
	$global:errors_count++
    $S="Deleting dynamic distribution group ""$($GroupName)"" DisplayName=""$($GroupDisplayName)"", Alias=""$($GroupAlias)"". Error = $($error[0])"
    log_message "ERROR" $S
    }
}
#
###############################################################################
#                                                                             #
#                                    Main                                     #
#                                                                             #
###############################################################################
#
$global:Version="V2.82"
#
# Office 365 params
#
$Office365Url="https://ps.outlook.com/powershell/"
$Office365LoginName="%OFFICE365_ADMIN%"
$Office365LoginPassword="%OFFICE365_PASSWORD%"
#
# Proxy parameters
#
$ProxyEnabled=$#BOOL{%PROXY_ENABLED%}
$ProxyUser="%PROXY_USER%"     
$ProxyPassword="%PROXY_PASSWORD%"
#
#
$LogFile=$MyInvocation.MyCommand.Definition 
$LogFile=$LogFile -replace(".ps1",".log")
$global:total_errors_count=0
welcome
check_version
connect $Office365Url $Office365LoginName $Office365LoginPassword $ProxyEnabled $ProxyUser $ProxyPassword
if ($global:total_errors_count -eq 0)
   {
   ### BEGIN_REPETITION ###
   $global:errors_count=0
   # KoXo Administrator's variables
   $DynamicDistributionGroupName="%SECONDARY_GROUP%"
   $DynamicDistributionGroupDisplayName="%SECONDARY_GROUP_DESC%"
   $DynamicDistributionGroupAlias="#LOWER{#REMOVE_SPACE{%SECONDARY_GROUP%}}"
   $DynamicDistributionGroupEmail="%PRIMARY_GROUP_EMAIL%"
   #
   log_message "Office 365" "$($DynamicDistributionGroupDisplayName) ($($DynamicDistributionGroupEmail))"
   if (dynamic_group_exists($DynamicDistributionGroupAlias))
      {
      $S="Dynamic distribution group : $($DynamicDistributionGroupAlias)"
      write-host $S
      delete_dynamic_distribution_group $DynamicDistributionGroupName $DynamicDistributionGroupAlias $DynamicDistributionGroupDisplayName $DynamicDistributionGroupEmail
      }
      else
      {
      $global:errors_count++
      $S="Dynamic distribution group ""$($DynamicDistributionGroupAlias)"" does not exists"
      write-host $S -foregroundcolor "red"
      log_message "ERROR" $S
      }
   log_errors_count $DynamicDistributionGroupName
   $global:total_errors_count=$global:total_errors_count+$global:errors_count
   ### END_REPETITION ###
   close
   }
log_total_errors_count
